Direct Chat Plugin | AdminLTE 3 Documentation
Description: AdminLTE v3 Documentaion

Direct Chat Plugin | AdminLTE v3 Documentaion

# Direct Chat Plugin

The direct chat plugin provides simple functionality to the direct chat component.

##### Usage

This plugin can be activated as a jQuery plugin or using the data api.

###### Data API

Add `data-widget="chat-pane-toggle"` to a button to activate the plugin.

    <button class="btn btn-primary" data-widget="chat-pane-toggle">Toggle Chat Pane</button>

###### jQuery

The jQuery API provides more customizable options that allows the developer to handle checking and unchecking the todo list checkbox events.

    $('#chat-pane-toggle').DirectChat('toggle')

##### Methods

Method | Description
--- | ---
toggle | Toggles the state of the chat pane between hidden and visible.

Example: `$('#chat-pane-toggle').DirectChat('toggle')`

##### Events

Event Type | Description
--- | ---
toggled.lte.directchat | Triggered after a direct chat contacts pane is toggled.

Example: `$('#toggle-button').on('toggled.lte.directchat', handleToggledEvent)`